@@ -60,6 +60,15 @@ print "$bv\n";
 printf "The integer value of the above bitvector shown as a string is:  %s\n", $bv->int_value();
 print "Size of the bitvector: " . $bv->length() . "\n";
 
+# Construct a bitvector of a specified length from a large integer:
+$bv =Algorithm::BitVector->new(intVal => Math::BigInt->new("89485765"), size => 32);
+print "\nHere is a bitvector of a specified size constructed from a large integer:\n";
+my $len= $bv->length();
+print "$bv\n";
+print "size of bitvec: $len\n";
+printf "The integer value of the above bitvector shown as a string is:  %s\n", $bv->int_value();
+print "Size of the bitvector: " . $bv->length() . "\n";
+
 # Construct a bitvector directly from a bit string:
 $bv = Algorithm::BitVector->new( bitstring => '00110011' );
 print "\nBitvector constructed directly from a bit string:\n";
@@ -74,14 +83,16 @@ print int($bv) . "\n";                            # 0
 print "\nConstructing a bitvector from the textstring 'hello':\n";
 my $bv3 = Algorithm::BitVector->new( textstring => "hello" );
 print "$bv3\n";              # 0110100001100101011011000110110001101111
-my $mytext = $bv3->get_text_from_bitvector();
+#my $mytext = $bv3->get_text_from_bitvector();
+my $mytext = $bv3->get_bitvector_in_ascii();
 print "Text recovered from the previous bitvector:\n";
 print "$mytext\n";                                         # hello
 print "\nConstructing a bitvector from the textstring 'hello\\njello':\n";
 $bv3 = Algorithm::BitVector->new( textstring => "hello\njello" );
 print "$bv3\n";            
   # 0110100001100101011011000110110001101111000010100110101001100101011011000110110001101111
-$mytext = $bv3->get_text_from_bitvector();
+#$mytext = $bv3->get_text_from_bitvector();
+$mytext = $bv3->get_bitvector_in_ascii();
 print "Text recovered from the previous bitvector:\n";
 print "$mytext\n";                                         # hello
                                                            # jello
@@ -90,7 +101,8 @@ print "$mytext\n";                                         # hello
 print "\nConstructing a bitvector from the hexstring '68656c6c6f':\n";
 my $bv4 = Algorithm::BitVector->new( hexstring => "68656c6c6f" );
 print "$bv4\n";             # 0110100001100101011011000110110001101111
-my $myhexstring = $bv4->get_hex_string_from_bitvector();
+#my $myhexstring = $bv4->get_hex_string_from_bitvector();
+my $myhexstring = $bv4->get_bitvector_in_hex();
 print "Hex string recovered from the previous bitvector: \n";
 print "$myhexstring\n";                                    # 68656c6c6f
 
