@@ -3,7 +3,7 @@ package Algorithm::BitVector;
 #!/usr/bin/perl -w
 
 #------------------------------------------------------------------------------------
-# Copyright (c) 2015 Avinash Kak. All rights reserved.  This program is free
+# Copyright (c) 2016 Avinash Kak. All rights reserved.  This program is free
 # software.  You may modify and/or distribute it under the same terms as Perl itself.
 # This copyright notice must remain attached to the file.
 #
@@ -21,7 +21,7 @@ use Math::BigInt;
 use Math::Random;
 use Fcntl 'SEEK_CUR';
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 use overload  '+'        =>    '_join',
               '""'       =>    '_str',
@@ -108,18 +108,27 @@ sub new {
             $self->{size} = 1;
         } else {
             my @bitarray;
-            if (ref($self->{intVal}) eq 'Math::BigInt') {
+#            if (ref($self->{intVal}) eq 'Math::BigInt') {
+            if (ref($self->{intVal}) eq 'Math::BigInt' && ! defined $self->{size}) {
                 my $bitlist_str = $self->{intVal}->as_bin();
+                $bitlist_str =~ s/^0b//;
                 @bitarray = split //, $bitlist_str;
-                # Now get rid of the `0b' prefix on the string returned by as_bin():
-                shift @bitarray;
-                shift @bitarray;
+            } elsif (ref($self->{intVal}) eq 'Math::BigInt' && defined $self->{size}) {   #new<<<<<<<<<<<<<
+                my $bitlist_str = $self->{intVal}->as_bin();
+                $bitlist_str =~ s/^0b//;
+                croak "\nThe value specified for size must be at least as large as for the " .
+                      "smallest bitvector possible for the intVal integer: $!" 
+                      if $self->{size} < length $bitlist_str;
+                @bitarray = split //, $bitlist_str;
+                my $n = $self->{size} - @bitarray;
+                my $extended_bitlist_str = '0' x $n . $bitlist_str;
+                @bitarray = split //, $extended_bitlist_str;
             } else {
                 my $bitlist_str = sprintf "%b", $self->{intVal};
                 if (defined $self->{size}) {
-                    die "The value specified for size must be at least as large as for the " .
-                        "smallest bitvector possible for the intVal integer: $!" 
-                        if $self->{size} < length $bitlist_str;
+                    croak "\nThe value specified for size must be at least as large as for the " .
+                          "smallest bitvector possible for the intVal integer: $!" 
+                          if $self->{size} < length $bitlist_str;
                     my $n = $self->{size} - length $bitlist_str;
                     my $extended_bitlist_str = '0' x $n . $bitlist_str;
                     @bitarray = split //, $extended_bitlist_str;
@@ -189,7 +198,7 @@ sub set_bit {
     my $self = shift;
     my $posn = shift;
     my $val = shift;
-    die "incorrect value for a bit" unless $val == 0 or $val == 1;
+    croak "incorrect value for a bit" unless $val =~ /\d/ &&  ($val == 0 or $val == 1);
     die "index range error" if  ($posn >= $self->{size}) or ($posn < - $self->{size});
     $posn = $self->{size} + $posn  if $posn < 0;
     my $block_index = int($posn / 16);
@@ -227,7 +236,7 @@ sub _str {
 ##  concatenated bitvector as a new BitVector instance.
 sub _join {
     my ($bv1, $bv2) = @_;
-    die "Abort: The concatenation operator invoked with either undefined " .
+    croak "Abort: The concatenation operator invoked with either undefined " .
         "or wrong types of operands: $!"
         unless UNIVERSAL::isa( $bv1, 'Algorithm::BitVector') and
         UNIVERSAL::isa( $bv2, 'Algorithm::BitVector');
@@ -237,7 +246,7 @@ sub _join {
 
 sub _compare {
     my ($bv1, $bv2) = @_;
-    die "Abort: The comparison operator invoked with either undefined " .
+    croak "Abort: The comparison operator invoked with either undefined " .
         "or wrong types of operands: $!"
         unless UNIVERSAL::isa( $bv1, 'Algorithm::BitVector') and
         UNIVERSAL::isa( $bv2, 'Algorithm::BitVector');
@@ -275,7 +284,7 @@ sub _invert {
 ## the left.
 sub _or {
     my ($bv1, $bv2) = @_;    
-    die "Abort: The `|' operator invoked with either undefined " .
+    croak "Abort: The `|' operator invoked with either undefined " .
         "or wrong types of operands: $!"
         unless UNIVERSAL::isa( $bv1, 'Algorithm::BitVector') and
         UNIVERSAL::isa( $bv2, 'Algorithm::BitVector');
@@ -313,7 +322,7 @@ sub _resize_pad_from_left {
 ##  left.
 sub _and {
     my ($bv1, $bv2) = @_;    
-    die "Abort: The concatenation operator invoked with either undefined " .
+    croak "Abort: The concatenation operator invoked with either undefined " .
         "or wrong types of operands: $!"
         unless UNIVERSAL::isa( $bv1, 'Algorithm::BitVector') and
         UNIVERSAL::isa( $bv2, 'Algorithm::BitVector');
@@ -342,7 +351,7 @@ sub _and {
 ##  left.
 sub _xor {
     my ($bv1, $bv2) = @_;    
-    die "Abort: The xor operator invoked with either undefined " .
+    croak "Abort: The xor operator invoked with either undefined " .
         "or wrong types of operands: $!"
         unless UNIVERSAL::isa( $bv1, 'Algorithm::BitVector') and
         UNIVERSAL::isa( $bv2, 'Algorithm::BitVector');
@@ -523,9 +532,10 @@ sub int_value {
 ##  left and replacing each byte by its ASCII character (this is a useful thing
 ##  to do only if the length of the vector is an integral multiple of 8 and every
 ##  byte in your bitvector has a print representation)
-sub get_text_from_bitvector {
+#sub get_text_from_bitvector {
+sub get_bitvector_in_ascii {
     my $self = shift;
-    die "Abort: The get_text_from_bitvector() method invoked on an object that is " .
+    die "Abort: The get_bitvector_in_ascii() method invoked on an object that is " .
         "not of type Algorithm::BitVector"
         unless UNIVERSAL::isa( $self, 'Algorithm::BitVector');
     die "\nThe bitvector for get_text_from_bitvector() must be an integral multiple of 8 bits: $!"
@@ -537,13 +547,20 @@ sub get_text_from_bitvector {
     return $ascii;
 }
 
+# for backward compatibility:
+sub get_text_from_bitvector {
+    my $self = shift;
+    $self->get_bitvector_in_ascii(@_);
+}
+
 ##  Return a string of hex digits by scanning the bits from the left and
 ##  replacing each sequence of 4 bits by its corresponding hex digit (this is a
 ##  useful thing to do only if the length of the vector is an integral multiple
 ##  of 4)
-sub get_hex_string_from_bitvector {
+#sub get_hex_string_from_bitvector {
+sub get_bitvector_in_hex {
     my $self = shift;
-    die "Abort: The get_hex_from_bitvector() method invoked on an object that is " .
+    die "Abort: The get_bitvector_in_hex() method invoked on an object that is " .
         "not of type Algorithm::BitVector"
         unless UNIVERSAL::isa( $self, 'Algorithm::BitVector');
     die "\nThe bitvector for get_hex_from_bitvector() must be a multiple of 4 bits: $!" 
@@ -555,6 +572,12 @@ sub get_hex_string_from_bitvector {
     return $hex;
 }
 
+# for backward compatibility:
+sub get_hex_string_from_bitvector {
+    my $self = shift;
+    $self->get_bitvector_in_hex(@_);    
+}
+
 ##  Read blocksize bits from a disk file and return a BitVector object containing
 ##  the bits.  If the file contains fewer bits than blocksize, construct the
 ##  BitVector object from however many bits there are in the file.  If the file
@@ -1185,6 +1208,10 @@ bit arrays and for logical and arithmetic operations on such arrays.
 
 =head1 CHANGES
 
+Version 1.25 incorporates bugfix for the case when you try to construct a bitvector
+of a specified length from a large integer that is supplied to the module constructor
+as a C<Math::BigInt> object.
+
 Version 1.24 includes in the C<Makefile.PL> file the minimum version restriction on
 the C<List::Util> module that is imported.
 
@@ -1257,15 +1284,15 @@ C<< <= >>, C<< > >>, C<< >= >>, C<< == >>, and C<< != >> operators.
                   '<>'       =>    '_iter',
                   'fallback' =>    1;
 
-It is B<important> to remember that the overloadings for the C<<< << >>> and C<<< >>
->>> operators are for B<circular> left and right shifts (their usual meaning as
+It is B<important> to remember that the overloadings for the `C<<< << >>>' and `C<<<
+>> >>>' operators are for B<circular> left and right shifts (their usual meaning as
 bitwise operators is for non-circular shifts).  This was done because the
 applications for which this module is intended is more likely to use circular shifts
 of bit fields than non-circular shifts.  You can still carry out non-circular shifts
 by calling the methods C<shift_left()> and C<shift_right()> as illustrated elsewhere
 in this documentation.
 
-Another B<important> thing to bear in mind is the overloading of the C<+> operator.
+Another B<important> thing to bear in mind is the overloading of the `C<+>' operator.
 It is B<NOT> addition.  On the other hand, it is a concatenation of the two operand
 bitvectors.  This was done to keep the usage of this operator the same as in the
 Python version of this module.
@@ -1629,28 +1656,13 @@ through 7, both ends inclusive.  Note that the slice is returned as an array of
 
 =back
 
-=head3 get_hex_string_from_bitvector()
-
-=over 4
-
-Assuming that length of your bitvector is a multiple of 4, this methods returns a
-hex representation of the bit pattern:
-
-    $bv = Algorithm::BitVector->new(bitstring => "0110100001100101011011000110110001101111");
-    print $bv->get_hex_string_from_bitvector();             # 68656c6c6f
-
-The hex representation is returned in the form if a string of hex characters.  This
-method throws an exception if the size of the bitvector is not a multiple of 4.
-
-=back
-
-=head3 get_text_string_from_bitvector()
+=head3 get_bitvector_in_ascii()
 
 =over 4
 
     $bv = Algorithm::BitVector->new( textstring => "hello" );
     print "$bv\n";                              # 0110100001100101011011000110110001101111 
-    print $bv->get_text_from_bitvector();                           # hello                        
+    print $bv->get_bitvector_in_ascrii();                           # hello                        
 
 The method returns a string of ASCII characters by converting successive 8-bit slices
 of the bitvector into an ASCII character. It throws an exception if the size of the
@@ -1665,6 +1677,21 @@ original text.
 
 =back
 
+=head3 get_bitvector_in_hex()
+
+=over 4
+
+Assuming that length of your bitvector is a multiple of 4, this methods returns a
+hex representation of the bit pattern:
+
+    $bv = Algorithm::BitVector->new(bitstring => "0110100001100101011011000110110001101111");
+    print $bv->get_bitvector_in_hex();             # 68656c6c6f
+
+The hex representation is returned in the form if a string of hex characters.  This
+method throws an exception if the size of the bitvector is not a multiple of 4.
+
+=back
+
 =head3 gf_divide_by_modulus()
 
 =over 4
@@ -1885,7 +1912,7 @@ that is set in a bitvector:
     print $bv->next_set_bit(5);                                  # 13                              
 
 In this example, we are asking the method to return the index of the bit that is set
-after the bit position indexed 5.
+after the bit position indexed 5.  The method returns -1 if there is no next set bit.
 
 =back
 
@@ -2209,10 +2236,10 @@ the string 'BitVector' in the subject line.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-BitVector-1.24.tar.gz
+    tar zxvf Algorithm-BitVector-1.25.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-BitVector-1.24>.  Enter this directory and execute the following commands
+C<Algorithm-BitVector-1.25>.  Enter this directory and execute the following commands
 for a standard install of the module if you have root privileges:
 
     perl Makefile.PL
@@ -2249,19 +2276,28 @@ reported by Dana Jacobsen in a bug report filed at C<rt.cpan.org>.  Thanks Dana!
 The restriction on the Perl version was removed on Slaven Rezic's recommendation.  He
 says the module runs fine with Perl 5.8.9.  Thanks Slaven!
 
+Austin Nobis reported a documentation error in Version 1.24 which was fixed in Version
+1.25.  Thanks Austin!
+
 =head1 AUTHOR
 
-Avinash Kak, kak@purdue.edu
+The author, Avinash Kak, recently finished a 17-years long "Objects Trilogy Project"
+with the publication of the book "Designing with Objects" by John-Wiley. If
+interested, visit his web page at Purdue to find out what this project was all
+about. You might like "Designing with Objects" especially if you enjoyed reading
+Harry Potter as a kid (or even as an adult, for that matter).
 
-If you send email, please place the string "BitVector" in your subject line to get past
-my spam filter.
+For all issues related to this module, contact the author at kak@purdue.edu
+
+If you send email, please place the string "BitVector" in your subject line to get
+    past the author's spam filter.
 
 =head1 COPYRIGHT
 
 This library is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
 
- Copyright 2015 Avinash Kak
+ Copyright 2016 Avinash Kak
 
 =cut
 
